package com.gic.enterprise.service;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.enterprise.dto.WmMemberCardConfigDTO;
import com.gic.enterprise.dto.WmOrderConfigDTO;
import com.gic.enterprise.dto.WmStoreDTO;
import com.gic.enterprise.dto.wm.WmStoreConfigDTO;

import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * 微盟商城店铺
 * @ClassName: WmStoreApiService 
 * @Description:  
 * @author guojuxing 
 * @date 2020/4/13 10:47 AM 
 */
public interface WmStoreApiService {

    /**
     * 新增
     * @Title: saveWmStore 
     * @Description:
     * @author guojuxing
     * @param wmStoreDTO 
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.Integer> 
     */
    ServiceResponse<Integer> saveWmStore(WmStoreDTO wmStoreDTO);

    /**
     * 修改
     * @Title: modifyWmStore 
     * @Description:
     * @author guojuxing
     * @param wmStoreDTO 
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.Void> 
     */
    ServiceResponse<Void> modifyWmStore(WmStoreDTO wmStoreDTO);

    /**
     * 微盟商城店铺授权
     * @Title: authWmStore 
     * @Description:
     * @author guojuxing
     * @param wmMallStoreId 
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.String> 店铺名称
     */
    ServiceResponse<String> authWmStore(Integer wmMallStoreId);

    ServiceResponse<List<WmStoreDTO>> listWmStore(Integer enterpriseId);

    ServiceResponse<WmStoreDTO> getWmStoreByWmMallStoreId(Integer wmMallStoreId);

    /**
     * 店铺配置
     * @Title: saveOrUpdateWmStoreConfig 
     * @Description:
     * @author guojuxing
     * @param dto 
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.Integer> 
     */
    ServiceResponse<Integer> saveOrUpdateWmStoreConfig(WmStoreConfigDTO dto);

    /**
     * 获取会员卡配置信息
     * @Title: getMemberCardConfig 
     * @Description:
     * @author guojuxing
     * @param wmMallStoreId 店铺主键
     * @return  com.gic.api.base.commons.ServiceResponse<com.gic.enterprise.dto.WmMemberCardConfigDTO> 
     */
    ServiceResponse<WmMemberCardConfigDTO> getMemberCardConfig(Integer wmMallStoreId);

    /**
     * 获取订单配置
     * @Title: getOrderConfig 
     * @Description:
     * @author guojuxing
     * @param wmMallStoreId 
     * @return  com.gic.api.base.commons.ServiceResponse<com.gic.enterprise.dto.WmOrderConfigDTO> 
     */
    ServiceResponse<WmOrderConfigDTO> getOrderConfig(Integer wmMallStoreId);

    /**
     * 根据微盟主账号查询配置
     * @Title: getWmStoreConfigByWmMainAccount 
     * @Description:
     * @author guojuxing
     * @param wmMainAccount 
     * @param wmStoreConfigType 店铺配置类型  WmStoreConfigTypeEnum 枚举类
     * @return  com.gic.api.base.commons.ServiceResponse<com.gic.enterprise.dto.wm.WmStoreConfigDTO> 
     */
    ServiceResponse<WmStoreConfigDTO> getWmStoreConfigByWmMainAccount(String wmMainAccount, Integer wmStoreConfigType);

    /**
     * 查询店铺配置  key : 配置类型 WmStoreConfigTypeEnum 枚举类
     * @Title: getWmStoreConfigByWmMainAccount 
     * @Description:
     * @author guojuxing
     * @param wmMainAccount 
     * @return  com.gic.api.base.commons.ServiceResponse<java.util.Set<String>> 
     */
    ServiceResponse<Set<String>> getWmStoreConfigByWmMainAccount(String wmMainAccount);
}
